use utf8;

package Data::OFAC::SDN::Schema;

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

use strict;
use warnings;

use base 'DBIx::Class::Schema';

__PACKAGE__->load_namespaces;

# Created by DBIx::Class::Schema::Loader v0.07037 @ 2013-11-11 16:42:43
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:hlmf52q5ptvG8WaMzioCSA

# You can replace this text with custom code or comments, and it will be preserved on regeneration
1;
